## Quiele ##
#### 0.0.2 ###
### Install ###
```python

pip install quiele

```

### Features ###
1. **Print with color tags**
    There are three modes each with it's own color

### Usage ###
```python

from quiele import ink
ink(50,mode="Metric")

```
